pub struct ListContainersOptions {
pub all: bool,
pub limit: Option<isize>,
pub size: bool,
pub filters: HashMap<String, Vec<String>>,
}Fields
all: boolReturn all containers. By default, only running containers are shown
limit: Option<isize>Return this number of most recently created containers, including non-running ones
size: boolReturn the size of container as fields SizeRw and SizeRootFs
filters: HashMap<String, Vec<String>>See Docker’s documentation to learn how to use filters https://docs.docker.com/reference/cli/docker/container/ls/#filter